@@ -1,7 +1,7 @@
 package App::DuckPAN::Web;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Webserver for duckpan server
-$App::DuckPAN::Web::VERSION = '0.177';
+$App::DuckPAN::Web::VERSION = '0.178';
 use Moo;
 use DDG::Request;
 use DDG::Test::Location;
@@ -18,7 +18,6 @@ use HTTP::Request;
 use LWP::UserAgent;
 use URI::Escape;
 use JSON;
-use open qw/:std :utf8/;
 
 has blocks => ( is => 'ro', required => 1 );
 has page_root => ( is => 'ro', required => 1 );
@@ -318,7 +317,10 @@ sub request {
 						last;
 					}
 					else{ # auto-template
-						my $template_name = 'goodie_'.scalar @{$structured->{input}}.'_inputs';
+						my $input_size = @{$structured->{input}};
+						die "Auto-templating with input of size $input_size called for '$structured->{operation}', "
+							. "while only sizes up to 2 are supported" if $input_size >= 3;
+						my $template_name = 'goodie_'.$input_size.'_inputs';
 						my $json_string = encode_json({Answer => $structured});
 						$zci_container->push_content(HTML::TreeBuilder->new_from_content("<script>\$(window).load(function(){"
 							. "document.getElementById('zci-answer').innerHTML = DDG.exec_template('$template_name', $json_string);"
@@ -533,7 +535,7 @@ App::DuckPAN::Web - Webserver for duckpan server
 
 =head1 VERSION
 
-version 0.177
+version 0.178
 
 =head1 AUTHOR
 
